scopusreport: Create reports using Scopus data automatically in Python
======================================================================

scopusreport is an easy way to generate reports using data from the Scopus database.

.. include:: installation.rst


=======
Classes
=======

Currently there is one class to interact with:

.. currentmodule:: scopusreport

There is one class to provide reports:

.. autosummary::

   report


==================
Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


.. Hidden links for Navigation side panel
.. toctree::
   :maxdepth: 2
   :hidden:

   examples
   reference
   changelog
   contributing
   authors
